
Push all available packages to a registry.

## Usage
```bash
autonomy push-all [OPTIONS]
```

## Options
`--packages-dir PATH`
:   Path to the packages directory.

`--help`
:   Show the help message and exit.

## Examples
Push all packages

```bash
autonomy push-all --packages-dir ./packages
```